@@ -36,10 +36,10 @@ class 普通邮件(object):   #直接发送，如果发送失败，可能导致
         encoders.encode_base64(attmt)
         self.msg.attach(attmt)
     def send(self):
-        rtmailcfg = configparser.ConfigParser()
+        swmailcfg = configparser.ConfigParser()
         dh,_=os.path.splitdrive(os.getcwd())
-        rtmailcfg.read(os.path.join(dh,"/etc","swmail.cfg"))
-        cfg=rtmailcfg[self.参数[0]]
+        swmailcfg.read(os.path.join(dh,"/etc","swmail.cfg"))
+        cfg=swmailcfg[self.参数[0]]
         smtp=smtplib.SMTP(cfg["smtpserver"])
         smtp.starttls()
         smtp.login(cfg["user"],cfg["password"])
