@@ -1,7 +1,7 @@
 #!/usr/bin/python3
 # -*- coding: utf8 -*-
 
-import libsw3 as sw3
+from libsw3 import *
 import os,getpass,json,urllib,hashlib,base64,sys
 
 class 代码管理(object):
@@ -87,7 +87,41 @@ class cks(object):
                         n2=f.read().decode("utf8")
                     #print("\n".join(diff.compare(n1.split("\n"),n2.split("\n"))))
                     print("\n".join(difflib.context_diff(n1.split("\n"),n2.split("\n"))))
-                    
+
+def convdbconf():
+    '''转换数据库配置文件'''
+    老配置文件=sw配置文件("oraconn.cfg")
+    if not os.path.isfile(老配置文件):
+        未完成退出("没找到 %s 文件",老配置文件)
+    f=open(老配置文件)
+    wjnr=f.readlines()
+    f.close()
+    模板=[
+        {
+                "db":"oracle",
+                "t":[],
+                "d":{
+                }
+        }
+]
+    新配置目录=sw配置文件("dbconn.config.d")
+    sw3.makedirs(新配置目录)
+    for i in wjnr:
+        if i.startswith("#"):
+            continue
+        s=i.split()
+        if len(s)!=2:
+            sw3.p(1,"格式错误:%s",i)
+            continue
+        s1,s2=s
+        模板[0]["t"]=[s2]
+        配置文件=os.path.join(新配置目录,"%s.cfg" %(s1))
+        print(配置文件)
+        if os.path.exists(配置文件):
+            异常退出("配置文件 %s 已经存在！",配置文件)
+        f=open(配置文件,"w")
+        f.write(json.dumps(模板,indent=4))
+        f.close()
 
 def main():
     sw3.start(globals(),"事务3辅助工具")
